==> weblog-1_40.tar.gz: weblog/language/x_brazilian_portuguese/blocks.php <==
<?php
/*
 * $Id: blocks.php,v 1.1 2005/03/16 16:13:10 tohokuaiki Exp $
 * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 * Translation for Brazilian Portuguese by giba@foxbrasil.com.br
 * 
 *

 */

define('_MB_RECENT_EDIT_NUMBER_OF_ENTRIES','Nmero de entradas a ser mostrado');
define('_MB_WEBLOG_EDIT_LINK_TO_LIST', 'Link authors to their entries? (0=No,1=Yes)'); //eng
define('_MB_RECENT_EDIT_MAX_TITLE_LENGTH','Tamanho mximo do titulo');
define('_MB_RECENT_EDIT_DATE_FORMAT','Formato da Data');
define('_MB_RECENT_EDIT_USE_AVATARS','Usar avatars? (0=No,1=Sim)');
define('_MB_RECENT_EDIT_TYPE','Type (1=pequeno,2=mdio,3=Grande)');

define('_MB_WEBLOG_LANG_TITLE', 'Title'); // eng
define('_MB_WEBLOG_LANG_AUTHOR', 'Author'); // eng
define('_MB_WEBLOG_LANG_COMMENTS', 'Comments'); // eng
define('_MB_WEBLOG_LANG_POSTED', 'Posted'); // eng
define('_MB_WEBLOG_LANG_READS', 'Reads'); // eng
define('_MB_WEBLOG_LANG_MOREWEBLOGS', 'More weBLogs'); // eng
?>

==> weblog-1_42.tar.gz: weblog/language/x_brazilian_portuguese/blocks.php <==
<?php
/*
 * $Id: blocks.php,v 1.3 2005/05/06 18:53:29 tohokuaiki Exp $
 * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 * Translation for Brazilian Portuguese by giba@foxbrasil.com.br
 * 
 *

 */
if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( 'WEBLOG_MB_LOADED' ) ) {

define( 'WEBLOG_MB_LOADED' , 1 ) ;

define('_MB_RECENT_EDIT_NUMBER_OF_ENTRIES','Nmero de entradas a ser mostrado');
define('_MB_WEBLOG_EDIT_LINK_TO_LIST', 'Link authors to their entries? (0=No,1=Yes)'); //eng
define('_MB_RECENT_EDIT_MAX_TITLE_LENGTH','Tamanho mximo do titulo');
define('_MB_RECENT_EDIT_DATE_FORMAT','Formato da Data');
define('_MB_RECENT_EDIT_USE_AVATARS','Usar avatars? (0=No,1=Sim)');
define('_MB_RECENT_EDIT_TYPE','Type (1=pequeno,2=mdio,3=Grande)');

define('_MB_WEBLOG_LANG_TITLE', 'Title'); // eng
define('_MB_WEBLOG_LANG_ENTRIES', 'Recent Entries'); // eng
define('_MB_WEBLOG_LANG_AUTHOR', 'Author'); // eng
define('_MB_WEBLOG_LANG_COMMENTS', 'Comments'); // eng
define('_MB_WEBLOG_LANG_POSTED', 'Posted'); // eng
define('_MB_WEBLOG_LANG_READS', 'Reads'); // eng
define('_MB_WEBLOG_LANG_MOREWEBLOGS', 'More weBLogs'); // eng

define('_MB_WEBLOG_USERS_SORT_READS', 'Total Reads'); // eng
define('_MB_WEBLOG_USERS_SORT_UPDATE', 'Last Entry'); // eng

}
?>
